aatools
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Install

You can install the package from Pypi using,

``` sh
pip install aatools
```

or, if you prefer conda with,

``` sh
conda install -c rcvalenzuela aatools
```

## How to use

Currently the package only provides one function
[`plot_univariate_continuous`](https://rcvalenzuela.github.io/aatools/eda.html#plot_univariate_continuous)
which given a sample of data from a univariate random variable generates
the histogram and adds information on the mean and the quartiles

Look at the [documentation](https://rcvalenzuela.github.io/aatools/) of
the package for information on how to use.
